package com.ruoyi.system.service.loan;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.loan.LoanSchedule;

import java.util.List;


/**
 * 业务进度Service接口
 * 
 * @author boman
 * @date 2024-04-24
 */
public interface ILoanScheduleService 
{
    /**
     * 查询业务进度
     * 
     * @param loanScheduleId 业务进度主键
     * @return 业务进度
     */
    public LoanSchedule selectLoanScheduleByLoanScheduleId(Long loanScheduleId);

    /**
     * 查询业务进度列表
     * 
     * @param loanSchedule 业务进度
     * @return 业务进度集合
     */
    public AjaxResult selectLoanScheduleList(LoanSchedule loanSchedule);

    /**
     * 新增业务进度
     * 
     * @param loanSchedule 业务进度
     * @return 结果
     */
    public int insertLoanSchedule(LoanSchedule loanSchedule);

    /**
     * 修改业务进度
     * 
     * @param loanSchedule 业务进度
     * @return 结果
     */
    public int updateLoanSchedule(LoanSchedule loanSchedule);

    /**
     * 批量删除业务进度
     * 
     * @param loanScheduleIds 需要删除的业务进度主键集合
     * @return 结果
     */
    public int deleteLoanScheduleByLoanScheduleIds(Long[] loanScheduleIds);

    /**
     * 删除业务进度信息
     * 
     * @param loanScheduleId 业务进度主键
     * @return 结果
     */
    public int deleteLoanScheduleByLoanScheduleId(Long loanScheduleId);
}
